Enum PassError Copy item path Source pub enum PassError {
PasswordStoreNotFound(PathBuf ),
InvalidStoreFormat(PathBuf , String ),
AmbiguousPassName(String ),
EntryNotFound(String ),
PathDecodingError(PathBuf ),
GpgKeyNotFoundError(String ),
IOError {
source: Error ,
},
GpgError {
source: Error ,
},
}Expand description Errors that may returned by library functions
Indication that there doesn’t exist a password store at a given location
The on-disk password store is somehow incorrectly formatted
The requested entry could not be clearly identified because it is ambiguous
The requested entry was not found in the password store
An on-disk path could not be correctly interpreted by this program
This can happen because rust imposes that all strings must be valid UTF-8 but some operating systems
don’t impose the same restrictions on their file paths.
When trying to convert from a path (which is represented using OsString ) to a
rust string, this error is returned.
A gpg key was tried to be loaded but it could not be
Some IO error occurred that is preserved as source
Some error occurred during entry interaction that is preserved as source
Formats the value using the given formatter.
Read more Formats the value using the given formatter.
Read more Returns the lower-level source of this error, if any.
Read more 👎 Deprecated since 1.42.0: use the Display impl or to_string()
👎 Deprecated since 1.33.0: replaced by Error::source, which can support downcasting
🔬 This is a nightly-only experimental API. (error_generic_member_access)
Provides type-based access to context intended for error reports.
Read more Converts to this type from the input type.
Converts to this type from the input type.
The error type produced by a failed conversion.
Convert the given value into an approximately equivalent representation.
The error type produced by a failed conversion.
Convert the subject into an approximately equivalent representation.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Approximate the subject with the default scheme.
Approximate the subject with a specific scheme.
Approximate the subject to a given type with the default scheme.
Approximate the subject to a given type with a specific scheme.
Convert the subject to a given type.
Attempt to convert the subject to a given type.
Attempt a value conversion of the subject to a given type.
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
Converts the given value to a
String.
Read more The error type produced by a failed conversion.
Convert the given value into the subject type.
The type returned in the event of a conversion error.
Performs the conversion.
The error type produced by a failed conversion.
Convert the subject into the destination type.
The type returned in the event of a conversion error.
Performs the conversion.
The error type produced by a failed conversion.
Convert the given value into an exactly equivalent representation.
The error type produced by a failed conversion.
Convert the subject into an exactly equivalent representation.