Struct StoreDirectoryRef

pub struct StoreDirectoryRef {
    pub path: PathBuf,
    pub content: HashSet<StoreEntry>,
}
A reference to a directory in the password store

Fields

path: PathBuf

Absolute path to the referenced directory

content: HashSet<StoreEntry>

Other entries that are contained in this directory

Implementations

Source

impl StoreDirectoryRef

pub fn name(&self) -> Result<String>

Retrieve the name of the store entry

The name is represented as a relative path from the store root and can be used to retrieve this entry using retrieve.

pub fn iter(&self) -> StoreDirectoryIter<'_>

iterate over all the entries contained in the storage hierarchy below this directory

Note: The iterator iterates over all entries even if they are in a subdirectory further down the storage hierarchy thus flattening it. If you want to iterate only over the entries contained directly in this directory, use the content field instead.