pub struct StoreFileRef {
    pub path: PathBuf,
}
A reference to a file in the password store

Fields

path: PathBuf

Absolute path to the referenced directory

Implementations

Retrieve the name of the store entry

The name is represented as a relative path from the store root and can be used to retrieve this entry using retrieve.

Get an IO handle to the encrypted content of this file

Get an IO handle to the plaintext content of this file