Struct libpass::StoreFileRef
source · [−]pub struct StoreFileRef {
pub path: PathBuf,
}Expand description
A reference to a file in the password store
Fields
path: PathBufAbsolute path to the referenced directory
Implementations
sourceimpl StoreFileRef
impl StoreFileRef
sourcepub fn name(&self) -> Result<String>
pub fn name(&self) -> Result<String>
Retrieve the name of the store entry
The name is represented as a relative path from the store root and can be used to retrieve this
entry using retrieve.
sourcepub fn cipher_io(&self) -> Result<CipherFile>
pub fn cipher_io(&self) -> Result<CipherFile>
Get an IO handle to the encrypted content of this file